@@ -5,8 +5,7 @@ Terrakio API Client
 An API client for Terrakio.
 """
 
-__version__ = "0.4.0"
-
+__version__ = "0.5.4"
 from terrakio_core import AsyncClient as CoreAsyncClient
 from terrakio_core import Client as CoreClient
 from functools import wraps
@@ -23,9 +22,53 @@ def create_blocked_method(original_method, reason=None):
     return blocked_method
 
 
+# User-facing wrappers to provide narrowed signatures with delegation
+class _UserMassStatsAsync:
+    def __init__(self, core_mass_stats):
+        self._ms = core_mass_stats
+
+    def __dir__(self):
+        attrs = [attr for attr in dir(self._ms) if not attr.startswith('_')]
+        wrapper_attrs = [attr for attr in object.__dir__(self) if not attr.startswith('_')]
+        # Ensure the narrowed method appears
+        if 'create_collection' not in wrapper_attrs:
+            wrapper_attrs.append('create_collection')
+        return list(set(attrs + wrapper_attrs))
+
+    def __getattr__(self, name):
+        return getattr(self._ms, name)
+
+    async def create_collection(self, collection: str, collection_type: str = "basic"):
+        """Create a collection. Admin-only params 'bucket' and 'location' are not available in this client."""
+        return await self._ms.create_collection(collection=collection, collection_type=collection_type)
+
+
+class _UserMassStatsSync:
+    def __init__(self, sync_wrapper):
+        # sync_wrapper is terrakio_core.sync_client.SyncWrapper over async mass_stats
+        self._sw = sync_wrapper
+
+    def __dir__(self):
+        attrs = [attr for attr in dir(self._sw) if not attr.startswith('_')]
+        wrapper_attrs = [attr for attr in object.__dir__(self) if not attr.startswith('_')]
+        if 'create_collection' not in wrapper_attrs:
+            wrapper_attrs.append('create_collection')
+        return list(set(attrs + wrapper_attrs))
+
+    def __getattr__(self, name):
+        return getattr(self._sw, name)
+
+    def create_collection(self, collection: str, collection_type: str = "basic"):
+        """Create a collection. Admin-only params 'bucket' and 'location' are not available in this client."""
+        return self._sw.create_collection(collection=collection, collection_type=collection_type)
+
+
 class AsyncClient(CoreAsyncClient):
+    mass_stats: "_UserMassStatsAsync"
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        # Rebind mass_stats to user-facing wrapper with narrowed signatures
+        self.mass_stats = _UserMassStatsAsync(self.mass_stats)
         self._apply_method_blocks()
     
     def _apply_method_blocks(self):
@@ -47,7 +90,7 @@ class AsyncClient(CoreAsyncClient):
                 'reason': 'not available for mass statistics(user_level)'
             },
             'groups': {
-                'methods': ['list_groups', 'get_groups', 'delete_group', 'create_group'],
+                'methods': ['list_groups_admin', 'get_group_admin', 'delete_group_admin', 'create_group_admin'],
                 'reason': 'not available for group management(user level)'
             },
             'space': {
@@ -71,9 +114,12 @@ class AsyncClient(CoreAsyncClient):
 
 class Client(CoreClient):
     """Synchronous version of the Terrakio API client with user-level restrictions."""
+    mass_stats: "_UserMassStatsSync"
     
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        # Rebind mass_stats to user-facing wrapper with narrowed signatures (sync)
+        self.mass_stats = _UserMassStatsSync(self.mass_stats)
         self._apply_method_blocks()
     
     def _apply_method_blocks(self):
@@ -95,7 +141,7 @@ class Client(CoreClient):
                 'reason': 'not available for mass statistics(user_level)'
             },
             'groups': {
-                'methods': ['list_groups', 'get_groups', 'delete_group', 'create_group'],
+                'methods': ['list_groups_admin', 'get_group_admin', 'delete_group_admin', 'create_group_admin'],
                 'reason': 'not available for group management(user level)'
             },
             'space': {
